#
# spec file for package python-sphinx-issues
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sphinx-issues
Version:        5.0.0
Release:        1.1
Summary:        A Sphinx extension for linking to a project's issue tracker
License:        MIT
URL:            https://github.com/sloria/sphinx-issues
Source:         https://github.com/sloria/sphinx-issues/archive/%{version}.tar.gz
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx
BuildArch:      noarch
%python_subpackages

%description
A Sphinx extension for linking to a project's issue tracker. It
includes roles for linking to issues as well as user profiles, with
built-in support for GitHub (though this works with other services).

%prep
%setup -q -n sphinx-issues-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/sphinx_issues
%{python_sitelib}/sphinx_issues-%{version}.dist-info

%changelog
* Thu Jan 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.0.0:
  * Remove :cwe: and :cve: roles, as these are officially included in
    Sphinx>=8.1.0.
  * Support Python 3.9-3.13. Python 3.8 is no longer supported.
- Clean up Python 2 remains.
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 4.1.0:
  * Add `:pypi:` role for linking to PyPI projects
  * Default to linking GH Sponsors for the :user: role
  * Support Python 3.8-3.12. Older versions are no longer supported.
  * Backwards-incompatible*: Remove ``__version__``,
    ``__author__``, and ``__license__`` attributes.
    Use ``importlib.metadata`` to read this metadata instead.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Apr 20 2022 pgajdos@suse.com
- version update to 3.0.1
  3.0.1 (2022-01-11)
  * Fix regression from 3.0.0: exception: 'in <string>' requires string as left operand, not type.
  3.0.0 (2022-01-10)
  * The :commit: role now outputs with an @ prefix.
  * Add configuration options for changing prefixes.
  * Allow {group} to be specified within issues_uri, issues_pr_uri, issues_commit_uri, and
  2.0.0 (2022-01-01)
  * Drop support for Python 2.7 and 3.5.
  * Test against Python 3.8 to 3.10.
  * Add :cwe: role for linking to CVEs on https://cwe.mitre.org. Thanks @hugovk for the PR.
  * Add support for custom urls and separators Issue #93
  * Allow custom titles for all roles Issue #116
  * Added setting issues_default_group_project as future replacement of issues_github_path,
    to reflect the now to universal nature of the extension
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Reduce bit conditionals as it is not needed
* Fri Apr 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  1.?.?
  * Add :commit: role for linking to commits.
  * Add support for linking to external repos.
  * Add :cve: role for linking to CVEs on https://cve.mitre.org.
  * Add :pr: role.
  * Drop support for Python 3.4.
  0.4.0
  * Raise ValueError if neither issues_uri nor issues_github_path
    is set.
  * Drop support for Python 2.6 and 3.3.
- take GitHub tarball because of the tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Aug 27 2017 jengelh@inai.de
- Update descriptions.
* Sat Aug 19 2017 sebix+novell.com@sebix.at
- initial package
